from . import BaseExtractor


class Riie(BaseExtractor):
    tag = "anime"
    host = "https://riie.jp"

    def extract(self, id: str) -> dict:
        """
        Ambil semua situs unduhan dan metadata dari halaman web

        Args:
              id: jalur url dimulai setelah host, type 'str'

        Returns:
              dict: hasil 'scrape' halaman web
        """

        raw = self.session.get(f"{self.host}/{id}")
        soup = self.soup(raw)

        if (eps := soup.findAll(id="episodes-list")):
            lst = {}
            for ep in eps:
                if (items := ep.findAll("li", class_="ep-item")):
                    title = ep.find(class_="gh-title").text

                    raw = {}
                    for item in items:
                        a = item.find("a")
                        if "download" in title.lower():
                            raw[a.text] = a["href"]
                        else:
                            raw[a.text] = "re:" + self.getPath(a["href"])
                    lst[title] = raw
            return lst

    def search(self, query: str, page: int = 1) -> list:
        """
        Cari item berdasarkan 'query' yang diberikan

        Args:
              query: kata kunci pencarian, type 'str'
              page: indeks halaman web, type 'int'

        Returns:
              list: daftar item dalam bentuk 'dict'
                    dengan struktur;

                    [
                      {
                        'id':  type 'str',
                        'title': type 'str'
                      }
                    ]
        """

        raw = self.session.get(f"{self.host}/search/{page}/{query}")
        soup = self.soup(raw)

        res = []
        if (result := soup.find(class_="filter-result")):
            for ul in result.findAll("ul"):
                for li in ul.findAll("li"):
                    a = li.find(class_="item-title").a
                    r = {
                        "id": self.getPath(a["href"]),
                        "title": a.text
                    }
                    for kl in ("tv-type", "gr-eps", "gr-type", "gr-sub"):
                        if (it := li.find(class_=kl)):
                            r[kl] = it.text
                    res.append(r)
        return res
