from . import BaseExtractor


class Wibudesu(BaseExtractor):
    host = "https://wibudesu.com"
    tag = "anime"

    def extract(self, id: str) -> dict:
        """
        Ambil semua situs unduhan dan metadata dari halaman web

        Args:
              id: jalur url dimulai setelah host, type 'str'

        Returns:
              dict: hasil 'scrape' halaman web
        """

        raw = self.session.get(f"{self.host}/{id}")
        soup = self.soup(raw)

        lexot = soup.find(class_="lexot")

        result = {}
        for p in lexot.findAll("p")[1:]:
            if (links := p.findAll("a")):
                title = p.strong.text
                d = {}
                for a in links:
                    d[a.text] = a["href"]
                result[title] = d
        return result

    def search(self, query: str, page: int = 1) -> list:
        """
        Cari item berdasarkan 'query' yang diberikan

        Args:
              query: kata kunci pencarian, type 'str'
              page: indeks halaman web, type 'int'

        Returns:
              list: daftar item dalam bentuk 'dict'
                    dengan struktur;

                    [
                      {
                        'id':  type 'str',
                        'title': type 'str'
                      }
                    ]
        """

        raw = self.session.get(f"{self.host}/page/{page}", params={
            "s": query, "post_type": "post"})
        soup = self.soup(raw)

        r = []
        for detpost in soup.findAll(class_="detpost"):
            a = detpost.find("a")
            result = {
                "title": a["title"],
                "id": self.getPath(a["href"])
            }

            if (morec := detpost.find(class_="morec")):
                result["genre"] = [a.text for a in morec.findAll("a")]

            r.append(result)
        return r
